MguHttpRequest class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
request(
{required MguHttpRequestMethod method, required String baseUrl, required MguHttpRequestInfo requestInfo, Duration sendTimeout = const Duration(seconds: 10), Duration connectTimeout = const Duration(seconds: 5), Duration receiveTimeout = const Duration(seconds: 15)}) → Future< MguHttpResponse>