MguHttpRequestInfo class

Constructors

MguHttpRequestInfo({required String apiPath, required bool hasMultipartFormData, Map<String, dynamic>? header, Map<String, dynamic>? data, Map<String, dynamic>? queryParameters, MguRetryInterceptor? retryInterceptor})
const

Properties

apiPath String
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
hasMultipartFormData bool
final
final
queryParameters Map<String, dynamic>?
final
retryInterceptor MguRetryInterceptor?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited